@@ -1356,7 +1356,7 @@ hdrl_collapse_imagelist_to_image_unwrap_eout(
                          void * eout)
 {
     if (f != NULL) {
-        return f->unwrap_eout(eout);
+        f->unwrap_eout(eout);
     }
 }
 
@@ -1440,7 +1440,7 @@ hdrl_collapse_imagelist_to_vector_unwrap_eout(
                          void * eout)
 {
     if (f != NULL) {
-        return f->unwrap_eout(eout);
+        f->unwrap_eout(eout);
     }
 }
 
