@@ -1257,12 +1257,14 @@ hdrl_parallel_filter_image(const cpl_image * img,
     }
     intptr_t hk = (ky / 2);
     cpl_image * res = cpl_image_new(nx, ny, cpl_image_get_type(img));
+    /* make sure image has a bpm to avoid creation races later */
+    cpl_image_get_bpm(res);
 
     cpl_ensure(ky % 2 == 1, CPL_ERROR_INCOMPATIBLE_INPUT, NULL);
     cpl_ensure(ny >= ky, CPL_ERROR_INCOMPATIBLE_INPUT, NULL);
     cpl_ensure(nx >= kx, CPL_ERROR_INCOMPATIBLE_INPUT, NULL);
     /* filter first half-kernel rows (needs full kernel image) */
-    {
+    if (hk) {
         const cpl_image * slice = image_const_row_view_create(img, 1, ky);
         cpl_image * slres = cpl_image_duplicate(slice);
         if (kernel) {
@@ -1284,7 +1286,7 @@ hdrl_parallel_filter_image(const cpl_image * img,
 HDRL_OMP(omp parallel for lastprivate(y) if (ny > s + ky))
     for (y = hk; y < ny - ky - (ny - ky) % s; y+=s) {
         intptr_t l = (y + 1) - hk;
-        intptr_t u = (y + 1 + s) + hk;
+        intptr_t u = (y + 1 + s) + hk - 1;
         const cpl_image * slice = image_const_row_view_create(img, l, u);
         cpl_image * slres = cpl_image_new(nx, u - l + 1,
                                           cpl_image_get_type(slice));
@@ -1295,14 +1297,14 @@ HDRL_OMP(omp parallel for lastprivate(y) if (ny > s + ky))
             cpl_image_filter_mask(slres, slice, mask, mode, border);
         }
         const cpl_image * slice2 =
-            image_const_row_view_create(slres, hk + 1, u - l - hk);
+            image_const_row_view_create(slres, hk + 1, hk + s);
         cpl_image_copy(res, slice2, 1, y + 1);
         image_const_row_view_delete(slice);
         image_const_row_view_delete(slice2);
         cpl_image_delete(slres);
     }
     /* filter remainder, needs half kernel overlap */
-    {
+    if (y + 1 - hk < ny) {
         const cpl_image * slice = image_const_row_view_create(img, y + 1 - hk, ny);
         cpl_image * slres = cpl_image_duplicate(slice);
         if (kernel) {
