@@ -525,6 +525,108 @@ xsh_params_set_defaults(cpl_parameterlist* pars,
 
 }
 
+static cpl_error_code
+xsh_qc_ifu_flat(cpl_frame* mflat,xsh_instrument* instrument)
+{
+    int do_it = 0;
+    if ( (xsh_instrument_get_arm(instrument) == XSH_ARM_UVB) ||
+                    (xsh_instrument_get_arm(instrument) == XSH_ARM_VIS) ) {
+        int binx=instrument->binx;
+        int biny=instrument->biny;
+        if( binx == 1 && biny == 1 ) {
+            do_it = 1;
+        }
+    } else {
+        if ( xsh_instrument_get_arm(instrument) == XSH_ARM_NIR ) {
+            do_it = 1;
+        }
+    }
+
+    if(do_it) {
+        xsh_pre* pre = xsh_pre_load(mflat,instrument);
+        double s1r;
+        double s2r;
+        double s3r;
+
+        double s1b;
+        double s2b;
+        double s3b;
+
+        if (xsh_instrument_get_arm(instrument) == XSH_ARM_UVB){
+
+
+            s1r=cpl_image_get_median_window(pre->data,1454,1500,1469,1600);
+            s2r=cpl_image_get_median_window(pre->data,1479,1500,1491,1600);
+            s3r=cpl_image_get_median_window(pre->data,1503,1500,1516,1600);
+
+            s1b=cpl_image_get_median_window(pre->data,515,2380,530,2380);
+            s2b=cpl_image_get_median_window(pre->data,541,2330,555,2380);
+            s3b=cpl_image_get_median_window(pre->data,566,2330,579,2380);
+
+        } else if (xsh_instrument_get_arm(instrument) == XSH_ARM_VIS){
+
+            s1r=cpl_image_get_median_window(pre->data,1652,2050,1666,2100);
+            s2r=cpl_image_get_median_window(pre->data,1674,2050,1684,2100);
+            s3r=cpl_image_get_median_window(pre->data,1697,2050,1711,2100);
+
+            s1b=cpl_image_get_median_window(pre->data,426,2650,444,2757);
+            s2b=cpl_image_get_median_window(pre->data,452,2650,470,2757);
+            s3b=cpl_image_get_median_window(pre->data,477,2650,496,2757);
+
+        } else if (xsh_instrument_get_arm(instrument) == XSH_ARM_NIR){
+
+            s1r=cpl_image_get_median_window(pre->data,620,1133,630,1175);
+            s2r=cpl_image_get_median_window(pre->data,636,1133,646,1175);
+            s3r=cpl_image_get_median_window(pre->data,653,1133,663,1175);
+
+            s1b=cpl_image_get_median_window(pre->data,128,1080,133,1111);
+            s2b=cpl_image_get_median_window(pre->data,141,1080,150,1111);
+            s3b=cpl_image_get_median_window(pre->data,158,1080,167,1111);
+
+        }
+        xsh_msg("s1b %g",s1b);
+        xsh_msg("s2b %g",s2b);
+        xsh_msg("s3b %g",s3b);
+
+        xsh_msg("s1r %g",s1r);
+        xsh_msg("s2r %g",s2r);
+        xsh_msg("s3r %g",s3r);
+
+        double A=(s2r-s2b)/s2r;
+        double m=(s1r+s2r+s3r)/3.0;
+        double a=(m-s1r)*(m-s1r);
+        double b=(m-s2r)*(m-s2r);
+        double c=(m-s3r)*(m-s3r);
+        double R=sqrt((a+b+c)/2.0);
+
+        double RD=(s1r-s3r)/(s1r+s2r)*2.0;
+
+        m=(s1b+s2b+s3b)/3.0;
+        a=(m-s1b)*(m-s1b);
+        b=(m-s2b)*(m-s2b);
+        c=(m-s3b)*(m-s3b);
+        double B=sqrt((a+b+c)/2.0);
+        double BD=(s1b-s3b)/(s1b+s2b)*2.0;
+
+        xsh_msg("FLUX_ORDER_RATIO %g",A);
+        xsh_msg("SLICE_RMS        %g",R);
+        xsh_msg("SLICE2_RMS       %g",B);
+        xsh_msg("SLICE_S_DIFF     %g",RD);
+        xsh_msg("SLICE2_S_DIFF    %g",BD);
+
+        cpl_propertylist_append_double(pre->data_header,"QC.FRATIO",A);
+        cpl_propertylist_append_double(pre->data_header,"QC.SLICER.RMS",R);
+        cpl_propertylist_append_double(pre->data_header,"QC.SLICEB.RMS",B);
+        cpl_propertylist_append_double(pre->data_header,"QC.SLICER.SDIFF",RD);
+        cpl_propertylist_append_double(pre->data_header,"QC.SLICEB.SDIFF",BD);
+        xsh_pre_save(pre,cpl_frame_get_filename(mflat),cpl_frame_get_tag(mflat),0);
+        xsh_pre_free(&pre);
+    }
+
+    return cpl_error_get_code();
+}
+
+
 
 /*--------------------------------------------------------------------------*/
 /**
@@ -706,7 +808,10 @@ static void xsh_mflat(cpl_parameterlist* parameters, cpl_frameset* frameset)
 
      xsh_msg("Detect dead-saturated pixels");
      check(xsh_image_mflat_detect_blemishes(master_flat_frame, instrument));
-
+     /* Temporarily disactivated */
+     if(xsh_instrument_get_mode(instrument) == XSH_MODE_IFU) {
+         xsh_qc_ifu_flat(master_flat_frame,instrument);
+     }
 
      /***********************************************************************/
      /* Products */
@@ -897,6 +1002,11 @@ static void xsh_mflat(cpl_parameterlist* parameters, cpl_frameset* frameset)
  
      xsh_msg("Detect dead-saturated pixels");
      check(xsh_image_mflat_detect_blemishes(master_flat_frame,instrument));
+     /* Temporarily disactivated */
+     if(xsh_instrument_get_mode(instrument) == XSH_MODE_IFU) {
+         xsh_qc_ifu_flat(master_flat_frame,instrument);
+     }
+
 
      check( xsh_add_product_pre( master_flat_frame, frameset,
                                  parameters, RECIPE_ID, instrument));
