@@ -454,7 +454,7 @@ xsh_respon_slit_stare(cpl_parameterlist* parameters,
   int recipe_use_model = 0 ;
   int do_optextract = 0;
   int do_flatfield = 1;
-  int do_compute_map = 0 ;
+  int do_compute_map = FALSE ;
   int generate_sdp_format = 0;
   // int do_compute_eff = 0 ;
   xsh_extract_param extract_par = {  LOCALIZATION_METHOD};
@@ -608,8 +608,8 @@ xsh_respon_slit_stare(cpl_parameterlist* parameters,
 
   check( do_sub_sky = xsh_parameters_subtract_sky_single_get_true( RECIPE_ID,
     parameters));
-  if ( (do_sub_sky && !do_compute_map) &&
-       (wavemap_frame == NULL || slitmap_frame == NULL) ) {
+
+  if ( do_sub_sky == 1   && (wavemap_frame == NULL || slitmap_frame == NULL) ) {
        xsh_msg_warning( "sky-subtract is true but wave,slits maps missing create them");
     do_compute_map = TRUE;
 
@@ -799,10 +799,17 @@ xsh_respon_slit_stare(cpl_parameterlist* parameters,
       single_frame_sky_sub_tab_frame, instrument, sub_sky_nbkpts2, sky_par,
       &sky_frame, &sky_frame_eso, &sky_frame_ima, rec_prefix,1));
 
-  xsh_add_temporary_file(cpl_frame_get_filename(slitmap_frame));
-  xsh_add_temporary_file(cpl_frame_get_filename(wavemap_frame));
+  if(slitmap_frame) {
+      xsh_add_temporary_file(cpl_frame_get_filename(slitmap_frame));
+  }
+
+  if(wavemap_frame) {
+      xsh_add_temporary_file(cpl_frame_get_filename(wavemap_frame));
+  }
+
   xsh_add_temporary_file(cpl_frame_get_filename(sub_sky2_frame));
 
+
   if(do_sub_sky) {
      xsh_add_temporary_file(cpl_frame_get_filename(sky_frame_ima));
   }
