@@ -435,7 +435,7 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
 {
    const char* recipe_tags[3] = {XSH_OBJECT_SLIT_STARE,
                                  XSH_STD_TELL_SLIT_STARE,
-				 XSH_STD_FLUX_SLIT_STARE};
+				                 XSH_STD_FLUX_SLIT_STARE};
   int recipe_tags_size = 3;
 
   /* Input frames */
@@ -454,29 +454,34 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
   cpl_frame *wavemap_frame = NULL ;
   cpl_frame *slitmap_frame = NULL ;
   cpl_frame *disp_tab_frame = NULL;
+
   cpl_frame *spectralformat_frame = NULL ;
   cpl_frame *tellmask_frame = NULL;
+
   /* Parameters */
-  //xsh_clipping_param* crh_clipping_par = NULL;
   xsh_background_param* backg_par = NULL;
-  xsh_remove_crh_single_param * crh_single_par = NULL ;
   xsh_rectify_param * rectify_par = NULL ;
-  xsh_localize_obj_param * loc_obj_par = NULL ;
   xsh_stack_param* stack_par=NULL;
+
+  xsh_remove_crh_single_param * crh_single_par = NULL ;
+  xsh_localize_obj_param * loc_obj_par = NULL ;
+
   int sub_sky_nbkpts1 = SUBTRACT_SKY_SINGLE_NBKPTS ; /**< Nb of breakpoints 
 						      for the first call to
 						      subtract_sky_single */
   int sub_sky_nbkpts2 = SUBTRACT_SKY_SINGLE_NBKPTS ; /**< Nb of breakpoints 
 						      for the second call to
 						      subtract_sky_single */
-  int do_sub_sky = FALSE;		/**< if 0 DO NOT subtract sky single */
-  int recipe_use_model = 0;
-  int do_optextract = 0;
-  int do_flatfield = 1;
+
   int do_compute_map = 0;
+
+  int recipe_use_model = 0;
+
+  int do_flatfield = 1;
+  int do_optextract = 0;
+  int do_sub_sky = FALSE;       /**< if 0 DO NOT subtract sky single */
   int generate_sdp_format = 0;
-  xsh_extract_param extract_par = 
-    { LOCALIZATION_METHOD };
+  xsh_extract_param extract_par = { LOCALIZATION_METHOD };
 
   xsh_opt_extract_param *opt_extract_par = NULL;
   xsh_subtract_sky_single_param *sky_par = NULL;
@@ -486,14 +491,13 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
   char rec_name[256];
 
   /* Intermediate frames */
-#if 0
-  cpl_frameset * on = NULL, * off = NULL ; /**< ON and Off frames (NIR only) */
-#endif
   cpl_frame * crhm_frame = NULL ;	/**< Output of remove_crh */
   //cpl_frame * rmbias = NULL;	/**< Output of subtract bias */
   cpl_frame * rmdark = NULL;	/**< Output of subtract dark */
   cpl_frame * rmbkg = NULL ;	/**< Output of subtract background */
   cpl_frame * div_frame = NULL ; /**< Output of xsh_divide_flat */
+
+
   cpl_frame * sub_sky_frame = NULL ; /**< Output of xsh_subtract_sky_single */
   cpl_frame * sub_sky2_frame = NULL ; /**< Output of xsh_subtract_sky_single
 				       Second pass (with localization table) */
@@ -538,6 +542,10 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
   cpl_frame * fluxframe = NULL;
   cpl_frame * uncalframe = NULL;
 
+
+
+
+
   cpl_frame* grid_backg=NULL;
   cpl_frame* frame_backg=NULL;
   cpl_frame* sky_frame_ima=NULL;
