@@ -219,9 +219,9 @@ static int xsh_scired_ifu_offset_create(cpl_plugin *plugin){
   check(xsh_parameters_clipping_crh_create(RECIPE_ID,recipe->parameters,
     crh_clip_param));
 
-  /* subtract_background_params */
+  /* subtract_background_params AMO removed these
   check(xsh_parameters_background_create(RECIPE_ID,recipe->parameters));
-
+  */
   /* remove_crh_single */
   check(xsh_parameters_remove_crh_single_create(RECIPE_ID,recipe->parameters,
 						crh_single )) ;
@@ -312,17 +312,9 @@ static int xsh_scired_ifu_offset_exec(cpl_plugin *plugin) {
 @return cpl_error_code
  */
 static cpl_error_code 
-xsh_params_monitor(xsh_background_param* backg,
-                   xsh_rectify_param * rectify_par)
+xsh_params_monitor(xsh_rectify_param * rectify_par)
 {
 
-
-  xsh_msg_dbg_low("bkg params: sampley=%d radius_y=%d",
-	  backg->sampley,backg->radius_y);
-
-  xsh_msg_dbg_low("bkg params: radius_x=%d",
-	  backg->radius_x);
-
   xsh_msg_dbg_low("rectify params: radius=%g bin_lambda=%g bin_space=%g",
 	  rectify_par->rectif_radius,rectify_par->rectif_bin_lambda,
 	  rectify_par->rectif_bin_space);
@@ -471,6 +463,8 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
   cpl_frame *spectral_format_frame = NULL;
   cpl_frame *ifu_cfg_tab_frame = NULL ;
   cpl_frame *ifu_cfg_cor_frame = NULL ;
+  int nobj=0;
+  int nsky=0;
 
   /* Input frames */
   cpl_frameset* raws = NULL;
@@ -484,13 +478,12 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
   cpl_frame* order_tab_edges = NULL;
   cpl_frame * wavesol_frame = NULL ;
   cpl_frame * model_config_frame = NULL ;
-  //cpl_frame * wavemap = NULL ;
   //cpl_frame * spectral_format = NULL ;
   cpl_frame * slice_offset_frame = NULL ;
-  cpl_frameset * object_frameset = NULL, * sky_frameset = NULL ;
+  cpl_frameset * raw_object = NULL, * raw_sky = NULL ;
   xsh_stack_param* stack_par=NULL;
   /* Parameters */
-  xsh_background_param* backg_par = NULL;
+  //xsh_background_param* backg_par = NULL;
   xsh_remove_crh_single_param * crh_single_par = NULL ;
   xsh_rectify_param * rectify_par = NULL ;
 
@@ -502,8 +495,7 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
   /* Intermediate frames */
 
   cpl_frameset * sub_frameset = NULL ;	/**< frameset of subtracted offset frames */
-  cpl_frameset * rmbkg_frameset = NULL ; /**< frameset of frames after 
-					  subtract bkg */
+  //cpl_frameset * rmbkg_frameset = NULL ; /**< frameset of frames after subtract bkg */
   cpl_frameset * clean_frameset = NULL ; /**< frameset of clean frames after
 					  divide flat */
   cpl_frame * comb_obj_frame = NULL ; /**< Comined frame */
@@ -527,18 +519,24 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
   //cpl_frameset * rect_frameset_tab=NULL;
   //cpl_frameset * rect_frameset_eso=NULL;
   char rec_prefix[256];
+  char sky_prefix[256];
   cpl_frame* object_frame=NULL;
   //int check_afc = TRUE;
   int do_compute_map = TRUE;
   int recipe_use_model = FALSE;
   char wave_map_tag[256];
   char slit_map_tag[256];
-  cpl_frame *wavemap_frame = NULL ;
-  cpl_frame *slitmap_frame = NULL ;
+  cpl_frame *wavemap = NULL ;
+  cpl_frame *slitmap = NULL ;
   cpl_frame *disp_tab_frame = NULL;
   cpl_frame* comb_sky_frame=NULL;
   int pre_overscan_corr=0;
   cpl_frame* ifu_sky_map=NULL;
+  int do_computemap=1;
+  int use_model=0;
+  cpl_frameset* crh_clean_obj = NULL;
+  cpl_frameset* crh_clean_sky = NULL;
+  int do_flatfield = 1;
   /**************************************************************************/
   /* DFS management */
   /**************************************************************************/
@@ -547,12 +545,10 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
                     RECIPE_ID, XSH_BINARY_VERSION,
                     xsh_scired_ifu_offset_description_short));
 
+  check(xsh_ensure_raws_input_offset_recipe_is_proper(&raws,instrument));
   assure( instrument->mode == XSH_MODE_IFU, CPL_ERROR_ILLEGAL_INPUT,
 	  "Instrument NOT in Ifu Mode" ) ;
-
   check(xsh_recipe_params_check(parameters,instrument,RECIPE_ID));
-
-  check(xsh_ensure_raws_input_offset_recipe_is_proper(&raws,instrument));
   /* One should have a multiple of 2 input frames: A-B */
   check( nb_raw_frames = cpl_frameset_get_size( raws ) ) ;
   xsh_msg( "Nb of Raw frames: %d", nb_raw_frames ) ;
@@ -564,9 +560,6 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
     XSH_ASSURE_NOT_ILLEGAL( even_nb == 0 ) ;
 
   }
- prefix=xsh_set_recipe_file_prefix(raws,"xsh_scired_ifu_offset");
- check(strcpy(rec_prefix,(const char*)prefix));
- XSH_FREE(prefix);
  
 
   /**************************************************************************/
@@ -627,8 +620,6 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
     xsh_error_reset();
   }
 
-  //check( wavemap = xsh_find_wavemap( calib, instrument ) ) ;
-  //check( spectral_format = xsh_find_spectral_format( calib, instrument ) ) ;
 
   if ((slice_offset_frame = xsh_find_frame_with_tag( calib, XSH_SLICE_OFFSET,
 						     instrument) ) == NULL ) {
@@ -642,9 +633,10 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
   /**************************************************************************/
   check( stack_par = xsh_stack_frames_get( RECIPE_ID, parameters));
 
+  /*
   check( backg_par = xsh_parameters_background_get(RECIPE_ID,
     parameters));
-
+  */
   check( rectify_par = xsh_parameters_rectify_get(RECIPE_ID,
      parameters));
   rectify_par->conserve_flux=FALSE;
@@ -658,11 +650,12 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
   }
   check(xsh_rectify_params_set_defaults(parameters,RECIPE_ID,instrument,rectify_par));
 
-  /* adjust relevant parameter to binning */
+  /* adjust relevant parameter to binning 
   if ( xsh_instrument_get_arm( instrument ) != XSH_ARM_NIR ) {
     check(xsh_params_bin_scale(raws,backg_par));
   }
-  check(xsh_params_monitor(backg_par,rectify_par));
+  */
+  check(xsh_params_monitor(rectify_par));
 
 
   /**************************************************************************/
@@ -673,28 +666,54 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
   check(xsh_prepare(raws, bpmap, master_bias, XSH_OBJECT_IFU_OFFSET,
 		    instrument,pre_overscan_corr,CPL_TRUE));
 
-
-
-/*
-  check(pairs=xsh_extract_obj_and_sky_pairs(raws,instrument));
-  xsh_free_frameset(&raws);
-  raws=cpl_frameset_duplicate(pairs);
-  xsh_free_frameset(&pairs);
-
-*/
+  /* make sure each input raw frame has the same exp time */
+  check(xsh_frameset_check_uniform_exptime(raws,instrument));
 
   /* Separate OBJECT and SKY frames */
   check( nb_sub_frames = xsh_dfs_split_offset( raws, "IFU_OFFSET",
-					   XSH_SKY_IFU, &object_frameset,
-					   &sky_frameset ) ) ;
+				   XSH_SKY_IFU, &raw_object,
+					   &raw_sky ) ) ;
+
+  nobj=cpl_frameset_get_size(raw_object);
+  nsky=cpl_frameset_get_size(raw_sky);
+  prefix=xsh_set_recipe_file_prefix(raws,"xsh_scired_ifu_offset");
+  sprintf(sky_prefix,xsh_set_recipe_sky_file_prefix(rec_prefix));
+  check(strcpy(rec_prefix,(const char*)prefix));
+  XSH_FREE(prefix);
+
+  xsh_msg("cmap=%d wavemap=%p slitmap=%p",do_computemap,wavemap,slitmap);
+  if( (do_computemap == 1) &&
+      (wavemap ==NULL || slitmap ==NULL )
+      ) {
+        if (model_config_frame != NULL) {
+          use_model=1;
+        }
+
+        check( xsh_check_get_map( disp_tab_frame, order_tab_edges,
+                master_flat, model_config_frame, calib, instrument,
+                do_computemap, use_model, rec_prefix,
+                &wavemap, &slitmap));
+
+  }
+
+  if( nb_sub_frames==0 ) {
+        xsh_msg_error("nb_sub_frames=%d something wrong check your input raws",nb_sub_frames);
+        goto cleanup;
+
+  }
+
+  /* remove crh on each obj or sky frame */
+  crh_clean_obj = xsh_frameset_crh_single(raw_object, crh_single_par,instrument,rec_prefix,"OBJ");
+  crh_clean_sky = xsh_frameset_crh_single(raw_sky, crh_single_par, instrument,rec_prefix,"SKY");
+
 
   /* For each pair, subtract OBJECT-SKY */
-  check( sub_frameset = xsh_subtract_sky_offset( object_frameset, sky_frameset,
+  check( sub_frameset = xsh_subtract_sky_offset( crh_clean_obj, crh_clean_sky,
 						 nb_sub_frames, instrument)) ;
 
 
 
-  check(object_frame=cpl_frameset_get_frame(object_frameset,0));
+  check(object_frame=cpl_frameset_get_frame(raw_object,0));
   if ( model_config_frame == NULL){
     xsh_msg("RECIPE USE WAVE SOLUTION");
     recipe_use_model = FALSE;
@@ -727,48 +746,22 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
   }
 */
 
-  if (recipe_use_model){
-       int found_temp=true;
-       xsh_msg("correct for temperature");
-       check(xsh_model_temperature_update_frame(&model_config_frame,
-                                                object_frame,
-                                                instrument,&found_temp));
+  if (do_flatfield == 1) {
+    clean_frameset=xsh_frameset_mflat_divide(sub_frameset,master_flat,instrument);
+  } else {
+    clean_frameset = cpl_frameset_duplicate(sub_frameset);
   }
-  if ( do_compute_map){
-     check(xsh_mode_set(instrument,XSH_MODE_IFU));
-
-    if (recipe_use_model){
+  /* now we have duplicate sub_frameset we do not need it anymore */
+  xsh_free_frameset(&sub_frameset);
 
 
-       sprintf(wave_map_tag,"%s_%s",rec_prefix,XSH_WAVE_MAP_MODEL);
-       sprintf(slit_map_tag,"%s_%s",rec_prefix,XSH_SLIT_MAP_MODEL);
-       check( xsh_create_model_map( model_config_frame, instrument,
-                                    wave_map_tag,slit_map_tag, 
-                                    &wavemap_frame, &slitmap_frame,1));
-
-    }
-    else{
-      xsh_msg( "Compute the wave map and the slit map");
-      check( xsh_create_map( disp_tab_frame, order_tab_edges,
-			     object_frame, instrument, 
-			     &wavemap_frame, &slitmap_frame,rec_prefix));
-    }
-    cpl_frameset_insert( calib, wavemap_frame);
-    cpl_frameset_insert( calib, slitmap_frame);
-  }
-  else{
-    check( wavemap_frame = xsh_find_wavemap( calib, instrument));
-    slitmap_frame = xsh_find_slitmap(calib, instrument);
-  }
-
-
-  check( rmbkg_frameset = cpl_frameset_new() ) ;
-  check( clean_frameset = cpl_frameset_new() ) ;
+  //check( rmbkg_frameset = cpl_frameset_new() ) ;
+  //check( clean_frameset = cpl_frameset_new() ) ;
 
   sprintf( arm_str, "%s_",  xsh_instrument_arm_tostring(instrument) ) ; 
 
-
-  /* For each sky subtracted frame */
+  /* AMO removed background subtraction 
+  // For each sky subtracted frame 
   for( i = 0 ; i<nb_sub_frames ; i++ ) {
     cpl_frame * a_b = NULL ;
     cpl_frame * rm_bkg = NULL ;
@@ -776,7 +769,7 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
 
     sprintf( str, "%d", i ) ;
     a_b = cpl_frameset_get_frame( sub_frameset, i ) ;
-    /* subtract background */
+    // subtract background 
 
     xsh_msg("Subtract inter-order background %d", i );
     sprintf(file_name,"%s%s",rec_prefix, str) ;
@@ -788,8 +781,10 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
 					    &frame_backg,0,0,0));
     check( cpl_frameset_insert( rmbkg_frameset, rm_bkg ) ) ;
   }
+  */
 
-
+  /* AMO removed this part doing CRH flagging and flat fielding
+     as these have been already performed
   if ( nb_sub_frames < 3 && crh_single_par->nb_iter > 0 ) {
     xsh_msg( "Less than 3 frames AND crh_single_niter > 0" ) ;
     for ( i = 0 ; i < nb_sub_frames ; i++ ) {
@@ -830,11 +825,11 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
     cpl_frame * a_b = NULL ;
     char str[16] ;
 
-    /* If enough frames, the CRH removal is done in xsh_combine_offset */
+    // If enough frames, the CRH removal is done in xsh_combine_offset 
     a_b = cpl_frameset_get_frame( rmbkg_frameset, i ) ;
     sprintf( str, "%d", i ) ;
 
-    /* Divide by flat */
+    /// Divide by flat
     xsh_msg( "Divide by flat" ) ;
     file_tag = xsh_stringcat_any( "FF_IFU_OFFSET_", arm_str,
 				   str, (void*)NULL ) ;
@@ -845,7 +840,7 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
     check( cpl_frameset_insert( clean_frameset, divided ) ) ;
     xsh_add_temporary_file(cpl_frame_get_filename(divided));
   }
-
+  */
 
   /* Now combine all frames */
   xsh_msg( "Combining all frames" ) ;
@@ -857,7 +852,7 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
 					  instrument, NULL, NULL,1 ) ) ;
   XSH_FREE( file_tag ) ;
 
-  check(comb_sky_frame=xsh_util_frameset_collapse_mean(sky_frameset,instrument));
+  check(comb_sky_frame=xsh_util_frameset_collapse_mean(raw_sky,instrument));
 
 
   /* Now build the cube frame */
@@ -880,13 +875,13 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
                            parameters,rectify_par,RECIPE_ID,rec_prefix,0));
 
   if(do_compute_map) {
-  check(ifu_sky_map=xsh_build_ifu_map(comb_obj_frame,wavemap_frame,slitmap_frame,instrument));
+  check(ifu_sky_map=xsh_build_ifu_map(comb_obj_frame,wavemap,slitmap,instrument));
   check( xsh_add_product_image( ifu_sky_map, frameset,parameters, RECIPE_ID, instrument,NULL));
   }
   cleanup:
  
     xsh_end( RECIPE_ID, frameset, parameters );
-    XSH_FREE( backg_par ) ;
+    //XSH_FREE( backg_par ) ;
     XSH_FREE( crh_single_par ) ;
     XSH_FREE( rectify_par ) ;
     XSH_FREE(stack_par);
@@ -895,13 +890,13 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
     xsh_free_frameset(&rect2_frameset_tables);
     xsh_free_frameset(&ext_frameset_tables);
 
-    xsh_free_frameset(&object_frameset);
-    xsh_free_frameset(&sky_frameset);
+    xsh_free_frameset(&raw_object);
+    xsh_free_frameset(&raw_sky);
     xsh_free_frameset(&raws);
     xsh_free_frameset(&calib);
     xsh_free_frameset( &sub_frameset ) ;
     xsh_free_frameset( &clean_frameset ) ;
-    xsh_free_frameset( &rmbkg_frameset ) ;
+    //xsh_free_frameset( &rmbkg_frameset ) ;
     xsh_free_frameset(&res_1D_frameset) ;
     xsh_free_frameset(&res_2D_frameset) ;
     xsh_free_frameset(&rect2_frameset) ;
