@@ -310,11 +310,7 @@ xsh_params_bin_scale(cpl_frameset* raws,
     For the moment not bin dependent, but for optimal results probably yes
     */
 
-    /*
-    loc_obj_par->loc_chunk_nb=loc_obj_par->loc_chunk_nb/biny;
-    Localization Nb of chunks.
-    Not bin dependent
-    */
+
   }
 
 
@@ -335,11 +331,6 @@ xsh_params_bin_scale(cpl_frameset* raws,
     For the moment not bin dependent, but for optimal results probably yes
     */
 
-    /*
-    loc_obj_par->nod_step=loc_obj_par->nod_step/binx;
-    Step (arcsec) between A and B images in nodding mode.
-    For the moment not bin dependent, but for optimal results probably yes
-    */
   }
  
  cleanup:
@@ -461,7 +452,7 @@ static void xsh_scired_ifu_stare(cpl_parameterlist* parameters,
 
   /* Beware, do not "free" the following input frames, they are part
      of the input frameset */
-  cpl_frame *spectral_format_frame = NULL;
+  cpl_frame *spectral_format = NULL;
   cpl_frame *ifu_cfg_tab_frame = NULL ;
   cpl_frame *ifu_cfg_cor_frame = NULL ;
 
@@ -471,32 +462,29 @@ static void xsh_scired_ifu_stare(cpl_parameterlist* parameters,
   cpl_frame *bpmap = NULL;
   cpl_frame *master_bias = NULL;
   cpl_frame *master_dark = NULL;
-  cpl_frame *masterflat_frame = NULL;
+  cpl_frame *master_flat = NULL;
   cpl_frame *order_tab_edges = NULL;
+
   cpl_frame *model_config_frame = NULL ;
-  cpl_frame *wavemap_frame = NULL ;
-  cpl_frame *slitmap_frame = NULL ;
+  cpl_frame *wavemap = NULL ;
+  cpl_frame *slitmap = NULL ;
   cpl_frame *disp_tab_frame = NULL;
 
   /* Parameters */
   xsh_background_param *backg_par = NULL;
   xsh_rectify_param *rectify_par = NULL ;
   xsh_stack_param* stack_par=NULL;
-  /* xsh_localize_obj_param *loc_obj_par = NULL ; */
 
   int do_compute_map = 0;
-  int do_trace_obj = 0;
 
   int recipe_use_model = FALSE;
   int check_afc = TRUE;
+  int do_trace_obj = 0;
 
   xsh_instrument* instrument = NULL;
   int nb_raw_frames;
 
   /* Intermediate frames */
-#if 0
-  cpl_frameset * on = NULL, * off = NULL ; /**< ON and Off frames (NIR only) */
-#endif
   cpl_frame * crhm_frame = NULL ;	/**< Output of remove_crh */
   cpl_frame * rmbias = NULL;	/**< Output of subtract bias */
   cpl_frame * rmdark = NULL;	/**< Output of subtract dark */
@@ -513,7 +501,7 @@ static void xsh_scired_ifu_stare(cpl_parameterlist* parameters,
   //cpl_frame* crh_frm=NULL;
   char tag[256];
   char name[256];
-  cpl_frame* wavesol_frame=NULL;
+  cpl_frame* wavesol=NULL;
   cpl_frame* order_tab_edges_frame=NULL;
 
   char wave_map_tag[256];
@@ -532,94 +520,34 @@ static void xsh_scired_ifu_stare(cpl_parameterlist* parameters,
 	  "Instrument NOT in IFU Mode");
 
   xsh_recipe_params_check(parameters,instrument,RECIPE_ID);
+  /**************************************************************************/
+  /* Recipe frames */
+  /**************************************************************************/
 
   /* One should have 1 or >=3 input frames. 2 is not permitted */
   check( nb_raw_frames = cpl_frameset_get_size( raws ) ) ;
   XSH_ASSURE_NOT_ILLEGAL( nb_raw_frames == 1 || nb_raw_frames >= 3 ) ;
+
+  if(nb_raw_frames>1) {
+    check(xsh_frameset_check_uniform_exptime(raws,instrument));
+  }
+
+  check( pre_overscan_corr = xsh_parameters_get_int( parameters, RECIPE_ID,
+                                                        "pre-overscan-corr"));
+
+
   prefix=xsh_set_recipe_file_prefix(raws,"xsh_scired_ifu_stare");
   check(strcpy(rec_prefix,(const char*)prefix));
   XSH_FREE(prefix);
-  /**************************************************************************/
-  /* Recipe frames */
-  /**************************************************************************/
-  check(bpmap=xsh_check_load_master_bpmap(calib,instrument,RECIPE_ID));
-  /* In UVB and VIS mode */
-  if ( xsh_instrument_get_arm(instrument) != XSH_ARM_NIR){
-    /* RAWS frameset must have only one file */
-    check( master_bias = xsh_find_master_bias(calib,instrument));
-  }
-#if 0
-  // Dont care ON/OFF in case of NIR (may change later)
-  /* IN NIR mode */
-  else {
-    /* split on and off files */
-    xsh_msg( "Calling xsh_dfs_split_nir" ) ;
-    check(xsh_dfs_split_nir(raws, &on, &off));
-    xsh_msg( "   Nb ON: %d, OFF: %d", cpl_frameset_get_size(on),
-	     cpl_frameset_get_size(off) ) ;
-    XSH_ASSURE_NOT_ILLEGAL(cpl_frameset_get_size(on) >= 3);
-    XSH_ASSURE_NOT_ILLEGAL(cpl_frameset_get_size(off) >= 3);
-  }
-#endif
-
-
-
-  /* IFU stuff (physmodel) */
-  check(ifu_cfg_tab_frame=xsh_find_frame_with_tag(calib,XSH_IFU_CFG_TAB,instrument));
-  check(ifu_cfg_cor_frame=xsh_find_frame_with_tag(calib,XSH_IFU_CFG_COR,instrument));
-  check(spectral_format_frame=xsh_find_spectral_format( calib, instrument ) ) ;
-
-  /* one should have either model config frame or wave sol frame */
-
- 
-  check( order_tab_edges = xsh_find_order_tab_edges( calib, instrument));
- 
-  /* one should have either model config frame or wave sol frame */
-   check(model_config_frame=xsh_find_frame_with_tag(calib,XSH_MOD_CFG_OPT_AFC,
-                                                    instrument));
-
-
-   if(model_config_frame==NULL) {
-      check(wavesol_frame=xsh_find_frame_with_tag(calib,XSH_WAVE_TAB_AFC,
-                                                  instrument));
-   }
-/*
-  wave_tabs_ifu = xsh_find_wave_tab_ifu( calib, instrument);
-  xsh_error_reset();
-*/
-  /*
-    One of model config and wave tab must be present, but only one !
-  */
-  if ( model_config_frame == NULL){
-    xsh_msg("RECIPE USE WAVE SOLUTION");
-    recipe_use_model = FALSE;
-  }
-  else{
-    xsh_msg("RECIPE USE MODEL");
-    recipe_use_model = TRUE;
-  }
-
-  if( (model_config_frame!=NULL) && (wavesol_frame != NULL) ) {
-    
-     xsh_msg_error("You cannot provide both a %s and a %s frame. Decide if you are in poly or physical model mode. We exit",
-                   XSH_WAVE_TAB_2D , XSH_MOD_CFG_TAB);
-     goto cleanup;                            
-  }   
-      
-  if((model_config_frame==NULL) && ( wavesol_frame == NULL) ) {
-     xsh_msg_error("You must provide either a %s or a %s frame",
-                   XSH_WAVE_TAB_AFC, XSH_MOD_CFG_TAB);
-     goto cleanup;
-  }
-
-  if ( (master_dark = xsh_find_master_dark( calib, instrument ) ) == NULL ){
-    xsh_msg_warning("Frame %s not provided",XSH_MASTER_DARK);
-    xsh_error_reset();
-  }
-
-  check( masterflat_frame = xsh_find_master_flat( calib, instrument));
+  xsh_msg("ok1");
+  check(xsh_ifu_stare_get_calibs(calib, instrument, &spectral_format, &master_bias,
+                           &master_dark, &master_flat, &order_tab_edges,
+                           &model_config_frame, &bpmap, &wavemap, &slitmap,
+                           &ifu_cfg_tab_frame, &ifu_cfg_cor_frame, &wavesol,
+                           RECIPE_ID, &recipe_use_model, pre_overscan_corr));
 
 
+  xsh_msg("ok2");
   /**************************************************************************/
   /* Recipe parameters */
   /**************************************************************************/
@@ -630,10 +558,7 @@ static void xsh_scired_ifu_stare(cpl_parameterlist* parameters,
   check( backg_par = xsh_parameters_background_get(RECIPE_ID,
     parameters));
 
-/*
-  check( loc_obj_par = xsh_parameters_localize_obj_get(RECIPE_ID,
-     parameters));
-*/
+
   check( rectify_par = xsh_parameters_rectify_get(RECIPE_ID,
      parameters));
   rectify_par->conserve_flux=FALSE;
@@ -659,8 +584,6 @@ static void xsh_scired_ifu_stare(cpl_parameterlist* parameters,
   check(xsh_params_monitor(backg_par,rectify_par));
 
 
-/*  XSH_ASSURE_NOT_ILLEGAL( loc_obj_par->loc_deg_poly <= 2); */
-
   /**************************************************************************/
   /* Recipe code */
   /**************************************************************************/
@@ -704,21 +627,21 @@ static void xsh_scired_ifu_stare(cpl_parameterlist* parameters,
        sprintf(slit_map_tag,"%s_%s",rec_prefix,XSH_SLIT_MAP_MODEL);
        check( xsh_create_model_map( model_config_frame, instrument,
                                     wave_map_tag,slit_map_tag, 
-                                    &wavemap_frame, &slitmap_frame,0));
+                                    &wavemap, &slitmap,0));
 
     }
     else{
       xsh_msg( "Compute the wave map and the slit map");
       check( xsh_create_map( disp_tab_frame, order_tab_edges,
 			     crhm_frame, instrument, 
-			     &wavemap_frame, &slitmap_frame,rec_prefix));
+			     &wavemap, &slitmap,rec_prefix));
     }
-    cpl_frameset_insert( calib, wavemap_frame);
-    cpl_frameset_insert( calib, slitmap_frame);
+    cpl_frameset_insert( calib, wavemap);
+    cpl_frameset_insert( calib, slitmap);
   }
   else{
-    check( wavemap_frame = xsh_find_wavemap( calib, instrument));
-    slitmap_frame = xsh_find_slitmap(calib, instrument);
+    check( wavemap = xsh_find_wavemap( calib, instrument));
+    slitmap = xsh_find_slitmap(calib, instrument);
   }
 
   /* NIR arm */
@@ -737,8 +660,8 @@ static void xsh_scired_ifu_stare(cpl_parameterlist* parameters,
         check(xsh_frame_check_model_cfg_is_proper_for_sci(model_config_frame,
                                                           rmbias,instrument));
      } else {
-        check(xsh_frame_check_model_cfg_is_afc_corrected(wavesol_frame));
-        check(xsh_frame_check_model_cfg_is_proper_for_sci(wavesol_frame,
+        check(xsh_frame_check_model_cfg_is_afc_corrected(wavesol));
+        check(xsh_frame_check_model_cfg_is_proper_for_sci(wavesol,
                                                           rmbias,instrument));
      }
   }
@@ -770,7 +693,7 @@ static void xsh_scired_ifu_stare(cpl_parameterlist* parameters,
   sprintf( tag, "%s_FF_%s", 
            rec_prefix,xsh_instrument_arm_tostring(instrument));
   sprintf(name,"%s.fits",tag);
-  check( div_frame = xsh_divide_flat( rmbkg, masterflat_frame, 
+  check( div_frame = xsh_divide_flat( rmbkg, master_flat,
       tag, instrument));
   xsh_add_temporary_file(name);
  
@@ -782,20 +705,20 @@ static void xsh_scired_ifu_stare(cpl_parameterlist* parameters,
      check(xsh_mode_set(instrument,XSH_MODE_SLIT));
      check(xsh_ifu_trace_object_calibrate(cpl_frame_get_filename(div_frame),
                                           cpl_frame_get_filename(order_tab_edges_frame),
-                                          cpl_frame_get_filename(slitmap_frame),
-                                          cpl_frame_get_filename(wavemap_frame)));
+                                          cpl_frame_get_filename(slitmap),
+                                          cpl_frame_get_filename(wavemap)));
   }
 
   check(xsh_build_ifu_cube(div_frame,ifu_cfg_tab_frame,ifu_cfg_cor_frame,
-                           spectral_format_frame,
+                           spectral_format,
                            model_config_frame,
-                           wavesol_frame,
+                           wavesol,
                            instrument,
                            frameset,
                            parameters,rectify_par,RECIPE_ID,rec_prefix,1));
 
   if(do_compute_map) {
-  check(ifu_sky_map=xsh_build_ifu_map(div_frame,wavemap_frame,slitmap_frame,instrument));
+  check(ifu_sky_map=xsh_build_ifu_map(div_frame,wavemap,slitmap,instrument));
   check( xsh_add_product_image( ifu_sky_map, frameset,parameters, RECIPE_ID, instrument,NULL));
   }
   cleanup:
