@@ -3,6 +3,7 @@ try:
 #  import sys
   import numpy
   import pyfits
+  import xsh_parameters_common
 #  import wx
 #  import matplotlib
   import reflex
@@ -650,147 +651,27 @@ try:
     # with the parameter list 
     # Note also that parameters have to be prefixed by the 'recipe name:'
 
-    def setGeneralParameters(self,paramList,rec_id):
-      group="general"
-      help1="""Integer representation of the bits to be considered bad when decoding the bad pixel mask pixel values.
-                    Most frequent codes relevant for the user:
-                    0: good pixel, 
-                    8: pick-up noise, 
-                    16: cosmic-ray removed, 
-                    32: cosmic-ray unremoved, 
-                    128: calibration file defect, 
-                    256: hot pixel, 
-                    512: dark pixel, 
-                    4096: A/D converted saturation, 
-                    32768: non linear pixel, 
-                    1048576: extrapolated flux in NIR, 
-                    4194304: Interpolated flux during extraction."""
-      #if rec_id[4:11] != "predict" and rec_id[4:12] != "orderpos" :
-
-      #   paramList.append(RecipeParameter(rec_id,displayName="decode-bp",group=group,description=help1))
-
-
-      help2="""pre-overscan correction.0: no correction1: mean overscan correction2: mean prescan correction3: (mean pre+mean overscan)/2 correction."""
-      paramList.append(RecipeParameter(rec_id,displayName="pre-overscan-corr",group=group,description=help2))
-
-
-    def setDetectArclinesParameters(self,paramList,rec_id):
-      group="detectarclines"
-      help1="""Half window size (HWS) in pixels for the line 2D fitting window (total window size = 2*HWS+1)."""
-      paramList.append(RecipeParameter(rec_id,displayName="detectarclines-fit-win-hsize",group=group,description=help1))
-
-      help2="""Half window size (HWS) in pixels for the line search box around the expected position (total window size = 2*HWS+1) [bin units]."""
-
-      paramList.append(RecipeParameter(rec_id,displayName="detectarclines-search-win-hsize",group=group,description=help2))
-
-
-      if rec_id[4:11] != "predict" :
-         help7="""Degree in Y in the polynomial order tracing X=f(Y)."""
-         paramList.append(RecipeParameter(rec_id,displayName="detectarclines-ordertab-deg-y",group=group,description=help7))
-
-
-      help8="""Minimum signal-to-noise ratio to filter lines"""
-      paramList.append(RecipeParameter(rec_id,displayName="detectarclines-min-sn",group=group,description=help8))
-
-
-    def setDetectContinuumParameters(self,paramList,rec_id):
-      group="detectcontinuum"
-
-      help1="""Half window size for the running median box during the search for the maximum in the cross-dispersion profile."""
-      paramList.append(RecipeParameter(rec_id,displayName="detectcontinuum-search-win-hsize",group=group,description=help1))
-
-      help2="""Half window size for the fit of the cross-dispersion profile."""
-      paramList.append(RecipeParameter(rec_id,displayName="detectcontinuum-running-win-hsize",group=group,description=help2))
-
-      help3="""Threshold factor applied to check that the flux at the fitted peak is higher than error."""
-      paramList.append(RecipeParameter(rec_id,displayName="detectcontinuum-fit-win-hsize",group=group,description=help3))
-
-      help4="""Degree in Y in the polynomial order tracing X=f(Y)."""
-      paramList.append(RecipeParameter(rec_id,displayName="detectcontinuum-ordertab-step-y",group=group,description=help4))
-
-      help5="""Maximum allowed residual (before kappa-sigma clip)."""
-      paramList.append(RecipeParameter(rec_id,displayName="detectcontinuum-ordertab-deg-y",group=group,description=help5))
-
-
-    def setDetectOrderParameters(self,paramList,rec_id):
-      group="detectorder"
-
-      help1="""Half window size in pixels for the search for order edges."""
-      paramList.append(RecipeParameter(rec_id,displayName="detectorder-edges-search-win-hsize",group=group,description=help1))
-
-      help2="""Threshold in relative flux (compared to the central flux) below which the order edges are defined."""
-      paramList.append(RecipeParameter(rec_id,displayName="detectorder-edges-flux-thresh",group=group,description=help2))
-
-      help3="""Minimum signal-to-noise ratio at the centroid of the orders (35 for SLIT-UVB,VIS, 20 for IFU-UVB,VIS, 25 for SLIT-NIR, 4 for IFU-NIR."""
-      paramList.append(RecipeParameter(rec_id,displayName="detectorder-min-sn",group=group,description=help3))
-
-      help11="""minimum signal noise ratio in order."""
-      paramList.append(RecipeParameter(rec_id,displayName="detectorder-d2-min-sn",group=group,description=help11))
-
-
-    def setBackgroundParameters(self,paramList,rec_id):
-      group="background"
-
-      help7="""X margin to order edge to define background sampling points."""
-      paramList.append(RecipeParameter(rec_id,displayName="background-edges-margin",group=group,description=help7))
-
-      help9="""Poly mode fit deg along Y. """
-      paramList.append(RecipeParameter(rec_id,displayName="background-poly-deg-y",group=group,description=help9))
-
-      help10="""Poly mode fit deg along X. """
-      paramList.append(RecipeParameter(rec_id,displayName="background-poly-deg-x",group=group,description=help10))
-
-      help11="""Poly mode kappa value of kappa-sigma-clip outliers
-                             removal. """
-      paramList.append(RecipeParameter(rec_id,displayName="background-poly-kappa",group=group,description=help11))
-
-    def setModelParameters(self,paramList,rec_id):
-      group="model"
-
-      help1="""Number/10 of annealing iterations if in physical model mode."""
-      paramList.append(RecipeParameter(rec_id,displayName="model-maxit",group=group,description=help1))
-
-      help2="""Multiplier applied to the automatic parameter ranges (i.e. when scenario!=0). For routine operations should be 1.0. (physical model mode)."""
-      paramList.append(RecipeParameter(rec_id,displayName="model-anneal-factor",group=group,description=help2))
-
-      help3="""selects preset flag and range combinations appropriate to common scenarios: 0 - No scenario, input cfg flags and limits used.1 - scenario appropriate for the startup recipe (large ranges for parameters affecting single ph exposures, dist coeff fixed).  2 - Like 1, but includes parameters affecting all ph positions.  3 - Scenario for use in fine tuning cfg to match routine single pinhole exposures. All parameters affecting 1ph exposures except dist coeffs are included and parameter ranges are small. (For use by predict in 1ph case).  4 - Like 3 but includes parameters  affecting all ph positions (Standard for use by predict in 9ph case and 2dmap)."""
-
-
-    def setStackParameters(self,paramList,rec_id):
-      group="stack"
-      help1="""Method used to build master frame. <median | mean>"""
-      paramList.append(RecipeParameter(rec_id,displayName="stack-method",group=group,description=help1))
-
-      help2="""Kappa used to clip low level values, when method is set to 'mean'."""
-      paramList.append(RecipeParameter(rec_id,displayName="klow",group=group,description=help2))
-
-      help3="""Kappa used to clip high level values, when method is set to 'mean'."""
-      paramList.append(RecipeParameter(rec_id,displayName="khigh",group=group,description=help3))
-
-      help4="""Number of kappa sigma iterations, when method is set to 'mean'."""
-
-
     def setInteractiveParameters(self):
       paramList = list()
       rec_id=self.rec_id
-
-      self.setGeneralParameters(paramList,rec_id)
-
+      self.par = xsh_parameters_common.Parameters()
+      self.par.setGeneralCalibParameters(paramList,rec_id)
+  
       if rec_id[4:11] == "predict" :
-         self.setDetectArclinesParameters(paramList,rec_id)
-         self.setModelParameters(paramList,rec_id)
+         self.par.setDetectArclinesParameters(paramList,rec_id)
+         self.par.setModelParameters(paramList,rec_id)
 
       elif rec_id[4:12] == "orderpos" :
-         self.setDetectContinuumParameters(paramList,rec_id)
+         self.par.setDetectContinuumParameters(paramList,rec_id)
 
       elif rec_id[4:9] == "mflat" :
-         self.setStackParameters(paramList,rec_id)
-         self.setDetectOrderParameters(paramList,rec_id)
-         self.setBackgroundParameters(paramList,rec_id)
+         self.par.setStackParameters(paramList,rec_id)
+         self.par.setDetectOrderParameters(paramList,rec_id)
+         self.par.setBackgroundParameters(paramList,rec_id)
 
       elif rec_id[4:9] == "2dmap" :
-         self.setDetectArclinesParameters(paramList,rec_id)
-         self.setModelParameters(paramList,rec_id)
+         self.par.setDetectArclinesParameters(paramList,rec_id)
+         self.par.setModelParameters(paramList,rec_id)
 
       elif rec_id[4:11] == "wavecal" :
          print "found wavecal params"
