@@ -1249,11 +1249,12 @@ xsh_count_satpix(xsh_pre* pre, xsh_instrument* instr,const int datancom)
         }
     }
     xsh_msg("nsat=%d",nsat);
-    xsh_pfits_set_nsat(pre->data_header,nsat);
+    xsh_pfits_set_total_nsat(pre->data_header,nsat);
     xsh_msg("datancom=%d",datancom);
     nsat_avg=nsat/datancom;
+    nsat_avg=((float)nsat/size);
     xsh_msg("nsat=%f",nsat_avg);
-    xsh_pfits_set_frac_sat(pre->data_header,nsat_avg);
+    xsh_pfits_set_total_frac_sat(pre->data_header,nsat_avg);
 
     cleanup:
      return cpl_error_get_code();
