@@ -1456,17 +1456,19 @@ xsh_rec_list_save2(xsh_rec_list* list,const char* filename, const char* tag)
 
   /* Loop over Orders, as we create one table per order */
   for( i = 0; i < list->size ; i++ ) {
+
     nlambda = list->list[i].nlambda ;
     nslit = list->list[i].nslit ;
     depth = nlambda*nslit ;
     order = list->list[i].order ;
 
     xsh_msg_dbg_high("depth %d : %dx%d", depth, nslit, nlambda);
-    
+
     /* skip the order */
     if (depth == 0){
       continue;
     }
+
     check( header_data = cpl_propertylist_duplicate( list->header));
     header_errs=cpl_propertylist_new();
     header_qual=cpl_propertylist_new();
@@ -1494,22 +1496,10 @@ xsh_rec_list_save2(xsh_rec_list* list,const char* filename, const char* tag)
       cdelt1=plambda[1]-plambda[0];
       crpix1=1.;
       crval1=plambda[0];
-      check( xsh_pfits_set_crpix1( header_data, crpix1));
-      check( xsh_pfits_set_crval1( header_data, crval1));
-      check( xsh_pfits_set_cdelt1( header_data, cdelt1));
-      check( cpl_propertylist_append_string( header_data,"CTYPE1","LINEAR"));
-
-
-      check( xsh_pfits_set_crpix1( header_errs, crpix1));
-      check( xsh_pfits_set_crval1( header_errs, crval1));
-      check( xsh_pfits_set_cdelt1( header_errs, cdelt1));
-      check( cpl_propertylist_append_string( header_errs,"CTYPE1","LINEAR"));
-
-      check( xsh_pfits_set_crpix1( header_qual, crpix1));
-      check( xsh_pfits_set_crval1( header_qual, crval1));
-      check( xsh_pfits_set_cdelt1( header_qual, cdelt1));
-      check( cpl_propertylist_append_string( header_qual,"CTYPE1","LINEAR"));
 
+      check(xsh_pfits_set_wcs1(header_data, crpix1, crval1, cdelt1));
+      check(xsh_pfits_set_wcs1(header_errs, crpix1, crval1, cdelt1));
+      check(xsh_pfits_set_wcs1(header_qual, crpix1, crval1, cdelt1));
 
       xsh_msg_dbg_high("write axis 1 : %f %f %f", crpix1, crval1, cdelt1);
 
@@ -1563,6 +1553,7 @@ xsh_rec_list_save2(xsh_rec_list* list,const char* filename, const char* tag)
     xsh_pfits_set_extname( header_errs, errs_extname);
     check(xsh_plist_set_extra_keys(header_errs,"IMAGE","DATA","RMSE",
                                    data_extname,errs_extname,qual_extname,1));
+
     check(cpl_image_save(img_err,filename, CPL_BPP_IEEE_FLOAT, 
 			   header_errs, CPL_IO_EXTEND)) ;
  
@@ -1571,6 +1562,7 @@ xsh_rec_list_save2(xsh_rec_list* list,const char* filename, const char* tag)
     xsh_pfits_set_extname( header_qual,qual_extname);
     check(xsh_plist_set_extra_keys(header_qual,"IMAGE","DATA","RMSE",
                                    data_extname,errs_extname,qual_extname,2));
+
     check(cpl_image_save(img_qual, filename, XSH_PRE_QUAL_BPP, 
 			   header_qual, CPL_IO_EXTEND)) ;
 
@@ -1590,6 +1582,7 @@ xsh_rec_list_save2(xsh_rec_list* list,const char* filename, const char* tag)
   check(result=xsh_frame_product(filename,tag,CPL_FRAME_TYPE_IMAGE, 
 				    CPL_FRAME_GROUP_PRODUCT,
 				    CPL_FRAME_LEVEL_FINAL));
+
   cleanup:
     xsh_free_propertylist( &header_data);
     XSH_TABLE_FREE( table);
