@@ -83,17 +83,11 @@ xsh_spectrum* xsh_spectrum_1D_create( double lambda_min, double lambda_max,
   result->lambda_step = lambda_step;
 
   XSH_NEW_PROPERTYLIST( result->flux_header);
-  check( xsh_pfits_set_crpix1( result->flux_header, 1.0));
-  check( xsh_pfits_set_crval1( result->flux_header, lambda_min));
-  check( xsh_pfits_set_cdelt1( result->flux_header, lambda_step));
-  check( xsh_pfits_set_ctype1( result->flux_header, "LINEAR"));
+  check(xsh_pfits_set_wcs1(result->flux_header, 1.0, lambda_min, lambda_step));
 
   XSH_NEW_PROPERTYLIST( result->errs_header);
   check( xsh_pfits_set_extname ( result->errs_header, "ERRS"));
-  check( xsh_pfits_set_crpix1( result->errs_header, 1.0));
-  check( xsh_pfits_set_crval1( result->errs_header, lambda_min));
-  check( xsh_pfits_set_cdelt1( result->errs_header, lambda_step));
-  check( xsh_pfits_set_ctype1( result->errs_header, "LINEAR"));
+  check(xsh_pfits_set_wcs1(result->errs_header, 1.0, lambda_min, lambda_step));
 
   XSH_NEW_PROPERTYLIST( result->qual_header);
   check( xsh_pfits_set_extname ( result->qual_header, "QUAL"));
@@ -155,14 +149,9 @@ xsh_spectrum* xsh_spectrum_2D_create( double lambda_min, double lambda_max,
   result->slit_step = slit_step; 
 
   XSH_NEW_PROPERTYLIST( result->flux_header);
-  check( xsh_pfits_set_crpix1( result->flux_header, 1.0));
-  check( xsh_pfits_set_crval1( result->flux_header, lambda_min));
-  check( xsh_pfits_set_cdelt1( result->flux_header, lambda_step));
-  check( xsh_pfits_set_crpix2( result->flux_header, 1.0));
-  check( xsh_pfits_set_crval2( result->flux_header, slit_min));
-  check( xsh_pfits_set_cdelt2( result->flux_header, slit_step));
-  check( xsh_pfits_set_ctype1( result->flux_header, "LINEAR"));
-  check( xsh_pfits_set_ctype2( result->flux_header, "LINEAR"));
+  check(xsh_pfits_set_wcs1(result->flux_header, 1.0, lambda_min, lambda_step));
+  check(xsh_pfits_set_wcs2(result->flux_header, 1.0, slit_min, slit_step));
+
   check(xsh_set_cd_matrix2d(result->flux_header));
 
   XSH_NEW_PROPERTYLIST( result->errs_header);
@@ -648,22 +637,20 @@ cpl_frame* xsh_spectrum_save( xsh_spectrum* s, const char* filename,
     crval1=xsh_pfits_get_crval1(s->flux_header);
     crpix1=xsh_pfits_get_crpix1(s->flux_header);
     cdelt1=xsh_pfits_get_cdelt1(s->flux_header);
+
+
+
     xsh_pfits_set_ctype1(s->flux_header,"LINEAR");
     xsh_pfits_set_cunit1(s->flux_header,"nm");
     cpl_propertylist_erase_regexp(s->flux_header, "^CTYPE2", 0);
 
 
-    xsh_pfits_set_crval1(s->errs_header,crval1);
-    xsh_pfits_set_crpix1(s->errs_header,crpix1);
-    xsh_pfits_set_cdelt1(s->errs_header,cdelt1);
-    xsh_pfits_set_cunit1(s->errs_header,"nm");
-    xsh_pfits_set_ctype1(s->errs_header,"LINEAR");
 
-    xsh_pfits_set_crval1(s->qual_header,crval1);
-    xsh_pfits_set_crpix1(s->qual_header,crpix1);
-    xsh_pfits_set_cdelt1(s->qual_header,cdelt1);
+    check(xsh_pfits_set_wcs1(s->errs_header, crpix1, crval1, crpix1));
+    xsh_pfits_set_cunit1(s->errs_header,"nm");
+
+    check(xsh_pfits_set_wcs1(s->qual_header, crpix1, crval1, crpix1));
     xsh_pfits_set_cunit1(s->qual_header,"nm");
-    xsh_pfits_set_ctype1(s->qual_header,"LINEAR");
     xsh_pfits_set_bunit(s->qual_header,XSH_BUNIT_NONE_C);
 
     check( flux1D = cpl_vector_new_from_image_row( s->flux, 1));
