@@ -493,7 +493,7 @@ cpl_frame* xsh_check_subtract_sky_single( int do_subsky, cpl_frame *src_frame,
   if ( do_subsky == CPL_TRUE){
     xsh_msg("---Sky subtraction (single frame)");
     check( result = xsh_subtract_sky_single( src_frame, ordertabedges_frame,
-      slitmap_frame, wavemap_frame, loctab_frame, masterflat_frame,
+      slitmap_frame, wavemap_frame, loctab_frame,
       definedbreakpoints_frame, instrument, nbkpts, sky_par, sky_spectrum,
 					     sky_spectrum_eso, prefix,clean_tmp));
    sprintf( result_tag,"%s_SKY_%s", prefix, 
@@ -582,7 +582,7 @@ void xsh_check_localize_and_nocrh( int nb_frames, loc_obj_par
 
     check( sub_sky_frame = xsh_subtract_sky_single( rmbkg, order_tab_edges,
                                                      slitmap_frame, wavemap_frame, 
-                                                     NULL, NULL,
+                                                     NULL,
                                                      single_frame_sky_sub_tab_frame,
                                                      instrument, 
                                                      sub_sky_nbkpts1, sky_par,
