@@ -26,7 +26,7 @@
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
-
+#define REGDEBUG_WAVECAL 0
 /*----------------------------------------------------------------------------*/
 /**
  * @defgroup drl_functions    DRL Functions
@@ -450,6 +450,7 @@ find_tilt( double yp0, double xc, float lambda, int ordnum,
     *nt = ntot;
     *ng = ngood;
 
+#if REGDEBUG_WAVECAL
     /* REGDEBUG */
     {
       FILE *fwhm_debug_file = NULL;
@@ -482,6 +483,7 @@ find_tilt( double yp0, double xc, float lambda, int ordnum,
       }
       fclose( fwhm_debug_file);
     }
+#endif
   }
   else{
     result = FIND_TILT_BAD_FIT;
