@@ -236,42 +236,18 @@ cpl_frame* xsh_format( cpl_frameset *spectrum_frame_set,
   check( xsh_pfits_set_pcatg( pre_3d->errs_header, pcatg));
   check( xsh_pfits_set_pcatg( pre_3d->qual_header, pcatg));
 
-
-
-
-  check( xsh_pfits_set_crpix1( pre_3d->data_header, 1.0));
-  check( xsh_pfits_set_crpix1( pre_3d->errs_header, 1.0));
-  check( xsh_pfits_set_crpix1( pre_3d->qual_header, 1.0));
-
-  check( xsh_pfits_set_crval1( pre_3d->data_header, -0.6));
-  check( xsh_pfits_set_crval1( pre_3d->errs_header, -0.6));
-  check( xsh_pfits_set_crval1( pre_3d->qual_header, -0.6));
-
-  check( xsh_pfits_set_cdelt1( pre_3d->data_header, 0.6));
-  check( xsh_pfits_set_cdelt1( pre_3d->errs_header, 0.6));
-  check( xsh_pfits_set_cdelt1( pre_3d->qual_header, 0.6));
-
+  check(xsh_pfits_set_wcs1(pre_3d->data_header, 1.0, -0.6, 0.6));
+  check(xsh_pfits_set_wcs1(pre_3d->errs_header, 1.0, -0.6, 0.6));
+  check(xsh_pfits_set_wcs1(pre_3d->qual_header, 1.0, -0.6, 0.6));
 
   check( xsh_pfits_set_crval2( pre_3d->data_header, crval2));
   check( xsh_pfits_set_crval2( pre_3d->errs_header, crval2));
   check( xsh_pfits_set_crval2( pre_3d->qual_header, crval2));
 
-  check( xsh_pfits_set_crpix3( pre_3d->data_header, 0.5));
-  check( xsh_pfits_set_crpix3( pre_3d->errs_header, 0.5));
-  check( xsh_pfits_set_crpix3( pre_3d->qual_header, 0.5));
+  check(xsh_pfits_set_wcs3(pre_3d->data_header, 0.5, lambda_min, lambda_step));
+  check(xsh_pfits_set_wcs3(pre_3d->errs_header, 0.5, lambda_min, lambda_step));
+  check(xsh_pfits_set_wcs3(pre_3d->qual_header, 0.5, lambda_min, lambda_step));
 
-  check( xsh_pfits_set_crval3( pre_3d->data_header, lambda_min));
-  check( xsh_pfits_set_crval3( pre_3d->errs_header, lambda_min));
-  check( xsh_pfits_set_crval3( pre_3d->qual_header, lambda_min));
-
-
-  check( xsh_pfits_set_cdelt3( pre_3d->data_header, lambda_step));
-  check( xsh_pfits_set_cdelt3( pre_3d->errs_header, lambda_step));
-  check( xsh_pfits_set_cdelt3( pre_3d->qual_header, lambda_step));
-
-  check( xsh_pfits_set_ctype3( pre_3d->data_header, "LINEAR"));
-  check( xsh_pfits_set_ctype3( pre_3d->errs_header, "LINEAR"));
-  check( xsh_pfits_set_ctype3( pre_3d->qual_header, "LINEAR"));
 
 /* the fdollowing should be done using more compact functions as: */
   check(xsh_set_cd_matrix3d(pre_3d->data_header));
@@ -552,17 +528,9 @@ cpl_frame* xsh_cube( cpl_frameset *merge2d_frameset,
   check( xsh_pfits_set_pcatg( pre_3d->qual_header, pcatg));
 
   /* slitlet direction */
-  check( xsh_pfits_set_crpix1( pre_3d->data_header, 1.0));
-  check( xsh_pfits_set_crpix1( pre_3d->errs_header, 1.0));
-  check( xsh_pfits_set_crpix1( pre_3d->qual_header, 1.0));
-
-  check( xsh_pfits_set_crval1( pre_3d->data_header, -0.6));
-  check( xsh_pfits_set_crval1( pre_3d->errs_header, -0.6));
-  check( xsh_pfits_set_crval1( pre_3d->qual_header, -0.6));
-
-  check( xsh_pfits_set_cdelt1( pre_3d->data_header, 0.6));
-  check( xsh_pfits_set_cdelt1( pre_3d->errs_header, 0.6));
-  check( xsh_pfits_set_cdelt1( pre_3d->qual_header, 0.6));
+  check(xsh_pfits_set_wcs1(pre_3d->data_header, 1.0, -0.6, 0.6));
+  check(xsh_pfits_set_wcs1(pre_3d->errs_header, 1.0, -0.6, 0.6));
+  check(xsh_pfits_set_wcs1(pre_3d->qual_header, 1.0, -0.6, 0.6));
 
   check( xsh_pfits_set_cunit1( pre_3d->data_header, "arcsec"));
   check( xsh_pfits_set_cunit1( pre_3d->errs_header, "arcsec"));
@@ -573,18 +541,9 @@ cpl_frame* xsh_cube( cpl_frameset *merge2d_frameset,
   check( crval2 = xsh_pfits_get_crval2(pre_cen->data_header));
   check( cdelt2 = xsh_pfits_get_cdelt2(pre_cen->data_header));
   
-  check( xsh_pfits_set_crpix2( pre_3d->data_header, crpix2));
-  check( xsh_pfits_set_crpix2( pre_3d->errs_header, crpix2));
-  check( xsh_pfits_set_crpix2( pre_3d->qual_header, crpix2));
-
-  check( xsh_pfits_set_crval2( pre_3d->data_header, crval2));
-  check( xsh_pfits_set_crval2( pre_3d->errs_header, crval2));
-  check( xsh_pfits_set_crval2( pre_3d->qual_header, crval2));
-
-  check( xsh_pfits_set_cdelt2( pre_3d->data_header, cdelt2));
-  check( xsh_pfits_set_cdelt2( pre_3d->errs_header, cdelt2));
-  check( xsh_pfits_set_cdelt2( pre_3d->qual_header, cdelt2));
-
+  check(xsh_pfits_set_wcs2(pre_3d->data_header, crpix2, crval2, cdelt2));
+  check(xsh_pfits_set_wcs2(pre_3d->errs_header, crpix2, crval2, cdelt2));
+  check(xsh_pfits_set_wcs2(pre_3d->qual_header, crpix2, crval2, cdelt2));
 
   check( xsh_pfits_set_cunit2( pre_3d->data_header, "arcsec"));
   check( xsh_pfits_set_cunit2( pre_3d->errs_header, "arcsec"));
@@ -593,22 +552,9 @@ cpl_frame* xsh_cube( cpl_frameset *merge2d_frameset,
   /* wavelength direction */
   check( crpix3 = xsh_pfits_get_crpix1( pre_cen->data_header));  
 
-  check( xsh_pfits_set_crpix3( pre_3d->data_header, crpix3));
-  check( xsh_pfits_set_crpix3( pre_3d->errs_header, crpix3));
-  check( xsh_pfits_set_crpix3( pre_3d->qual_header, crpix3));
-
-  check( xsh_pfits_set_crval3( pre_3d->data_header, crval3));
-  check( xsh_pfits_set_crval3( pre_3d->errs_header, crval3));
-  check( xsh_pfits_set_crval3( pre_3d->qual_header, crval3));
-
-
-  check( xsh_pfits_set_cdelt3( pre_3d->data_header, cdelt3));
-  check( xsh_pfits_set_cdelt3( pre_3d->errs_header, cdelt3));
-  check( xsh_pfits_set_cdelt3( pre_3d->qual_header, cdelt3));
-
-  check( xsh_pfits_set_ctype3( pre_3d->data_header, "LINEAR"));
-  check( xsh_pfits_set_ctype3( pre_3d->errs_header, "LINEAR"));
-  check( xsh_pfits_set_ctype3( pre_3d->qual_header, "LINEAR"));
+  check(xsh_pfits_set_wcs3(pre_3d->data_header, crpix3, crval3, cdelt3));
+  check(xsh_pfits_set_wcs3(pre_3d->errs_header, crpix3, crval3, cdelt3));
+  check(xsh_pfits_set_wcs3(pre_3d->qual_header, crpix3, crval3, cdelt3));
 
   check( xsh_pfits_set_cunit3( pre_3d->data_header, "nm"));
   check( xsh_pfits_set_cunit3( pre_3d->errs_header, "nm"));
