@@ -198,7 +198,7 @@ add_qc_crh (xsh_pre* pre, int nbcrh, int nframes)
   qc_crrate =
     (double) nbcrh / (((double) nframes) * (pre->exptime * 
     (pre->pszx / 10000.0) * (pre->pszy /10000.0) * pre->nx * pre->ny)) ;
-  nbcr_avg = nbcrh/nframes ;
+  nbcr_avg = (float)nbcrh/nframes ;
 
   /*
     Now set QC KW
@@ -206,6 +206,7 @@ add_qc_crh (xsh_pre* pre, int nbcrh, int nframes)
   check( xsh_pfits_set_qc_crrate( pre->data_header,qc_crrate) ) ;
   check( xsh_pfits_set_qc_ncrh( pre->data_header, nbcrh) ) ;
   check( xsh_pfits_set_qc_ncrh_mean( pre->data_header,nbcr_avg) ) ;
+  check( xsh_pfits_set_qc_ncrh_tot( pre->data_header,nbcrh) ) ;
   /* Same thing for the qual header */
   check( xsh_pfits_set_qc_crrate( pre->qual_header,qc_crrate)) ;
   check( xsh_pfits_set_qc_ncrh( pre->qual_header,nbcrh)) ;
@@ -364,6 +365,7 @@ xsh_remove_cosmics (cpl_frameset * rawFrames,
   char name[256];
   char result_name[256];
   const int mode_and = 0;
+  int ncrh_tot = 0;
 
   /* Check parameters */
   XSH_ASSURE_NOT_NULL( instr);
@@ -394,6 +396,10 @@ xsh_remove_cosmics (cpl_frameset * rawFrames,
     check_msg( cpl_imagelist_set(errsList,cpl_image_duplicate(pre->errs), 
       i),"Can't add Data Image %d to imagelist", i) ;
 
+    if(cpl_propertylist_has(pre->data_header,XSH_QC_CRH_NUMBER)) {
+       ncrh_tot += xsh_pfits_get_qc_ncrh(pre->data_header);
+    }
+
     /* combining bad pixels */
     if (i == 0) {
       qual_comb = cpl_image_duplicate(pre->qual);
@@ -406,7 +412,7 @@ xsh_remove_cosmics (cpl_frameset * rawFrames,
       xsh_pre_free(&pre);
     }
   }
-
+ 
   /*free memory on product extensions that will be re-allocated later on (errs is only modified) */
     xsh_free_image(&pre->data);
     xsh_free_image(&pre->qual);
@@ -448,9 +454,25 @@ xsh_remove_cosmics (cpl_frameset * rawFrames,
    */
   sprintf(result_name, "%s.fits", result_tag);
   xsh_msg_dbg_high("save frame %s tag=%s", result_name, result_tag);
+ 
+  if(strstr(result_tag,"DARK") != NULL) {
+     if(!cpl_propertylist_has(pre->data_header,XSH_QC_CRH_NUMBER_TOT)) {
+         xsh_pfits_set_qc_ncrh_tot(pre->data_header,ncrh_tot);
+     }
+     if(!cpl_propertylist_has(pre->data_header,XSH_QC_CRH_NUMBER_MEAN)) {
+         xsh_pfits_set_qc_ncrh_mean(pre->data_header,(float)ncrh_tot/size);
+     }
+  } else {
+     //if(!cpl_propertylist_has(pre->data_header,XSH_QC_CRH_NUMBER_TOT)) {
+         xsh_pfits_set_qc_ncrh_tot(pre->data_header,ncrh_tot);
+         //}
+         //if(!cpl_propertylist_has(pre->data_header,XSH_QC_CRH_NUMBER_MEAN)) {
+         xsh_pfits_set_qc_ncrh_mean(pre->data_header,(float)ncrh_tot/size);
+         //}
+  }
   check(medFrame = xsh_pre_save( pre, result_name, result_tag,save_tmp));
   check(cpl_frame_set_tag(medFrame, result_tag));
-
+ 
   //AMo: add crh map save for QC
   if ((crh_mask != NULL) && ((crh_ima) != NULL)) {
     xsh_free_image(crh_ima);
