@@ -1584,9 +1584,119 @@ xsh_flux_calibrate(cpl_frame* rect2D,
 }
 
 
+cpl_error_code
+xsh_ifu_stare_get_calibs(cpl_frameset* calib,
+                          xsh_instrument* inst,
+                          cpl_frame** spectral_format,
+                          cpl_frame** mbias,
+                          cpl_frame** mdark,
+                          cpl_frame** mflat,
+                          cpl_frame** otab_edges,
+                          cpl_frame** model_cfg,
+                          cpl_frame** bpmap,
+                          cpl_frame** wmap,
+                          cpl_frame** smap,
+                          cpl_frame** ifu_cfg_tab,
+                          cpl_frame** ifu_cfg_cor,
+                          cpl_frame** wavesol,
+                          const char* rec_id,
+                          int * recipe_use_model,
+                          int pscan)
+{
+
+    cpl_boolean mode_phys;
+    mode_phys=xsh_mode_is_physmod(calib,inst);
+    check(*spectral_format = xsh_find_spectral_format( calib, inst));
+
+    XSH_ASSURE_NOT_NULL_MSG(*spectral_format,"Null input spectral format frame");
+    check(xsh_instrument_update_from_spectralformat(inst,*spectral_format));
+
+    /* In UVB and VIS mode */
+
+    if (pscan == 0) {
+       xsh_msg("pscan=%d",pscan);
+        if ( xsh_instrument_get_arm(inst) != XSH_ARM_NIR){
+           /* RAWS frameset must have only one file */
+           if((*mbias = xsh_find_master_bias( calib, inst)) == NULL) {
+              xsh_msg_error("You must give a MASTER_BIAS_ARM frame");
+              return CPL_ERROR_DATA_NOT_FOUND;
+           }
+        }
+    }
+
+    /* IFU stuff (physmodel) */
+    check(*ifu_cfg_tab = xsh_find_frame_with_tag(calib,XSH_IFU_CFG_TAB,inst));
+    check(*ifu_cfg_cor = xsh_find_frame_with_tag(calib,XSH_IFU_CFG_COR,inst));
+    check(*spectral_format=xsh_find_spectral_format( calib, inst ) ) ;
+
+    /* one should have either model config frame or wave sol frame */
+    check( *model_cfg = xsh_find_frame_with_tag(calib,XSH_MOD_CFG_OPT_AFC, inst));
+    if( *model_cfg == NULL) {
+        check(*wavesol=xsh_find_frame_with_tag(calib,XSH_WAVE_TAB_AFC, inst));
+    }
+    /*
+     wave_tabs_ifu = xsh_find_wave_tab_ifu( calib, instrument);
+     xsh_error_reset();
+     */
+    /* One of model config and wave tab must be present, but only one ! */
+    if ( *model_cfg == NULL){
+        xsh_msg("RECIPE USE WAVE SOLUTION");
+        recipe_use_model = FALSE;
+    }
+    else{
+        xsh_msg("RECIPE USE MODEL");
+        recipe_use_model = TRUE;
+    }
+
+    if( ( *model_cfg !=NULL) && (*wavesol != NULL) ) {
+
+        xsh_msg_error("You cannot provide both a %s and a %s frame. Decide if you are in poly or physical model mode. We exit",
+                        XSH_WAVE_TAB_2D , XSH_MOD_CFG_TAB);
+        goto cleanup;
+    }
+
+    if(( *model_cfg == NULL) && ( *wavesol == NULL) ) {
+        xsh_msg_error("You must provide either a %s or a %s frame",
+                        XSH_WAVE_TAB_AFC, XSH_MOD_CFG_TAB);
+        goto cleanup;
+    }
+
+    if ( ( *mdark = xsh_find_master_dark( calib, inst ) ) == NULL ){
+        xsh_msg_warning("Frame %s not provided",XSH_MASTER_DARK);
+        xsh_error_reset();
+    }
+
+    check( *mflat = xsh_find_master_flat( calib, inst));
+    if( *mflat == NULL) {
+        xsh_msg_error("Frame %s not provided",XSH_MASTER_FLAT);
+        goto cleanup;
+    }
+    check( *otab_edges = xsh_find_order_tab_edges( calib, inst));
+    if( *otab_edges == NULL) {
+         xsh_msg_error("Frame %s not provided",XSH_ORDER_TAB_EDGES_IFU);
+         goto cleanup;
+    }
+
+    /* optional frames */
+    check(*bpmap=xsh_check_load_master_bpmap(calib,inst,rec_id));
+    check(*wmap = xsh_find_frame_with_tag(calib,XSH_WAVE_MAP,inst));
+    check(*smap = xsh_find_frame_with_tag(calib,XSH_SLIT_MAP,inst));
+
+    cleanup:
+
+    return cpl_error_get_code();
+
+}
+
+
+
+
+
+
+
 
 cpl_error_code
-xsh_slit_stare_get_calibs(cpl_frameset* calib, 
+xsh_slit_stare_get_calibs(cpl_frameset* calib,
                           xsh_instrument* instrument,
                           cpl_frame** spectralformat,
                           cpl_frame** mbias,
